@@ -1,6 +1,10 @@
+use RT::Record ();
 package RT::Record;
 
 use strict;
+use warnings;
+use warnings FATAL => 'redefine';
+
 use RTx::Shredder::Constants;
 
 =head2 _AsString
@@ -18,6 +22,29 @@ sub _AsString
 	return $res;
 }
 
+=head2 _AsInsertQuery
+
+Returns INSERT query string that duplicates current record and
+can be used to insert record back into DB after delete.
+
+=cut
+
+sub _AsInsertQuery
+{
+	my $self = shift;
+
+	my $dbh = $RT::Handle->dbh;
+
+	my $res = "INSERT INTO ". $dbh->quote_identifier( $self->Table );
+	my $values = $self->{'values'};
+	$res .= "(". join( ",", map { $dbh->quote_identifier( $_ ) } sort keys %$values ) .")";
+	$res .= " VALUES";
+	$res .= "(". join( ",", map { $dbh->quote( $values->{$_} ) } sort keys %$values ) .")";
+	$res .= ";";
+
+	return $res;
+}
+
 =head2 Dependencies
 
 =cut
@@ -47,6 +74,41 @@ sub Dependencies
 
 sub __DependsOn
 {
+	my $self = shift;
+	my %args = (
+			Shredder => undef,
+			Dependencies => undef,
+			@_,
+		   );
+	my $deps = $args{'Dependencies'};
+	my $list = [];
+
+# Object custom field values
+	my $objs = $self->CustomFieldValues;
+	$objs->{'find_expired_rows'} = 1;
+	push( @$list, $objs );
+
+# Object attributes
+	$objs = $self->Attributes;
+	push( @$list, $objs );
+
+# Transactions
+	$objs = RT::Transactions->new( $self->CurrentUser );
+	$objs->Limit( FIELD => 'ObjectType', VALUE => ref $self );
+	$objs->Limit( FIELD => 'ObjectId', VALUE => $self->id );
+	push( @$list, $objs );
+
+# ACE records
+	$objs = RT::ACL->new( $self->CurrentUser );
+	$objs->LimitToObject( $self );
+	push( @$list, $objs );
+
+	$deps->_PushDependencies(
+			BaseObj => $self,
+			Flags => DEPENDS_ON,
+			TargetObjs => $list,
+			Shredder => $args{'Shredder'}
+		);
 	return;
 }
 
@@ -157,8 +219,10 @@ sub __Wipeout
 	my $self = shift;
 	my %args = ( @_ );
 	my $msg = $self->_AsString ." deleted";
+	my $insert_query = $self->_AsInsertQuery;
 
 	$self->SUPER::Delete();
+	$args{'Shredder'}->DumpSQL( Query => $insert_query );
 
 	my $rec = $args{'Shredder'}->GetRecord( Object => $self );
 	$rec->{'State'} |= WIPED;
