@@ -88,8 +88,7 @@ sub rewrite_rtconfig
 
 	# generic logging
 	$RT::LogToSyslog = undef;
-	$RT::LogToScreen = 'error';
-	$RT::LogStackTraces = '1';
+	$RT::LogToScreen = undef;
 
 	# logging to standalone file
 	$RT::LogToFile = 'debug';
@@ -127,8 +126,6 @@ sub init_db
 	$fname = File::Spec->catfile( $RT::LocalEtcPath, 'initialdata' );
 	__insert_data( $fname ) if -f $fname && -r _;
 	RT::Init();
-	$SIG{__WARN__} = sub { $RT::Logger->warning( @_ ); warn @_ };
-	$SIG{__DIE__} = sub { $RT::Logger->crit( @_ ) unless $^S; die @_ };
 }
 
 sub __init_schema
@@ -361,21 +358,6 @@ sub connect_sqlite
 	return DBI->connect("dbi:SQLite:dbname=". shift, "", "");
 }
 
-=head2 SHREDDER
-
-=head3 shredder_new
-
-=cut
-
-sub shredder_new
-{
-    my $obj = new RTx::Shredder;
-    my $file = File::Spec->catfile( tmpdir(), test_name() .'.XXXX.sql' );
-    $obj->SetFile( FileName => $file, FromStorage => 0 );
-    return $obj;
-}
-
-
 =head2 TEST FILES
 
 =head3 test_name
@@ -411,8 +393,6 @@ Creates tmp dir if doesn't exist. Returns tmpdir absolute path.
 
 =cut
 
-sub create_tmpdir { my $n = tmpdir(); File::Path::mkpath( $n );	return $n }
-
 =head3 cleanup_tmp
 
 Delete all tmp files that match C<t/data/tmp/test_name.*> mask.
@@ -422,10 +402,14 @@ See also C<test_name> function.
 
 sub cleanup_tmp
 {
-	my $mask = File::Spec->catfile( tmpdir(), test_name() ) .'.*';
+	my $name = test_name();
+	my $dname = File::Spec->catdir(Cwd::cwd(), qw(t data tmp));
+	my $mask = File::Spec->catfile($dname, $name ) .'.*';
 	return unlink glob($mask);
 }
 
+sub create_tmpdir { my $n = tmpdir(); File::Path::mkpath( $n );	return $n; }
+
 =head2 SAVEPOINTS
 
 =head3 savepoint_name
@@ -446,42 +430,34 @@ sub savepoint_name
 Creates savepoint DB from the current.
 Takes name of the savepoint as argument.
 
-=head3 restore_savepoint
-
-Restores current DB to savepoint state.
-Takes name of the savepoint as argument.
-
 =cut
 
-sub create_savepoint { return __cp_db( db_name() => savepoint_name( shift ) ) }
-sub restore_savepoint { return __cp_db( savepoint_name( shift ) => db_name() ) }
-sub __cp_db
+sub create_savepoint
 {
-	my( $orig, $dest ) = @_;
+	my $orig = db_name();
+	my $dest = savepoint_name( shift );
 	$RT::Handle->dbh->disconnect;
-	# DIRTY HACK: undef Handles to force reconnect
-	$RT::Handle = undef;
-    %DBIx::SearchBuilder::DBIHandle = ();
-    $DBIx::SearchBuilder::PrevHandle = undef;
+
+	# undef Handle to force reconnect
+	undef $RT::Handle;
 
 	File::Copy::copy( $orig, $dest ) or die "Couldn't copy '$orig' => '$dest': $!";
-	RT::ConnectToDatabase();
+	RT::ConnectToDatabase;
 	return;
 }
 
-
 =head2 DUMPS
 
 =head3 dump_sqlite
 
 Returns DB dump as complex hash structure:
-    {
+{
 	TableName => {
 		#id => {
 			lc_field => 'value',
 		}
 	}
-    }
+}
 
 Takes named argument C<CleanDates>. If true clean all date fields from
 dump. True by default.
@@ -523,7 +499,7 @@ sub dump_current_and_savepoint
 	my $orig = savepoint_name( shift );
 	die "Couldn't find savepoint file" unless -f $orig && -r _;
 	my $odbh = connect_sqlite( $orig );
-	return ( dump_sqlite( $RT::Handle->dbh, @_ ), dump_sqlite( $odbh, @_ ) );
+	return ( dump_sqlite( $RT::Handle->dbh ), dump_sqlite( $odbh ) );
 }
 
 =head3 dump_savepoint_and_current
@@ -554,7 +530,7 @@ Function that return debug notes.
 
 =head3 note_on_fail
 
-Returns note about debug info you can find if test failed.
+Returns note about debug info you can find if test file fails.
 
 =cut
 
@@ -573,21 +549,6 @@ See also perldoc t/utils.pl to know how to use this info.
 END
 }
 
-=head3 note_not_patched
-
-Returns note about patch if RT looks like not patched.
-
-=cut
-
-sub note_not_patched
-{
-	return <<END;
-Couldn't find deleted ticket, may be you didn't patch
-your RT. Please, read README about how, when and why you
-have to patch your RT.
-END
-}
-
 =head2 OTHER
 
 =head3 is_all_seccessful
